@@ -36,28 +36,13 @@ SequencesParser <- R6::R6Class(
 #'
 #' Describes peptide sequences of biotech drugs
 #'
-#' @inheritSection run_all_parsers read_drugbank_xml_db
-#' @inheritParams run_all_parsers
-#'
 #' @return  a tibble with the following variables:
 #' \describe{
 #'  \item{sequence}{a textual representation of the sequence}
 #'  \item{format}{Currently, only the FASTA format is used}
 #'  \item{\emph{drugbank_id}}{drugbank id}
 #' }
-#' @family drugs
-#'
-#' @inherit run_all_parsers examples
-#' @export
-drug_sequences <- function(save_table = FALSE, save_csv = FALSE,
-                                 csv_path = ".", override_csv = FALSE,
-                           database_connection = NULL) {
-  SequencesParser$new(
-    save_table,
-    save_csv,
-    csv_path,
-    override_csv,
-    database_connection,
-    "drug_sequences"
-  )$parse()
+#' @keywords internal
+drug_sequences <- function() {
+  SequencesParser$new("drug_sequences")$parse()
 }
